$set 3 #Configmenu

$ #ConfigOptions
# Ayarlar
$ #FocusModel
# Foksleme
$ #WindowPlacement
# Pencere yerleimi
$ #ImageDithering
# Resim oluturmas
$ #OpaqueMove
# Ekran ierikli ta
$ #FullMax
# Tam ekranla, vallahi
$ #FocusNew
# Yeni pencereleri foksle
$ #FocusLast
# Masastndeki son pencereyi foksle
$ #ClickToFocus
# Tklayarak foksle
$ #SloppyFocus
# Ar foksle
$ #AutoRaise
# Otomatikman ykselt
$ #SmartRows
# Akll yerleim( Sralar )
$ #SmartCols
# Akll yerleim( Stunlar )
$ #Cascade
# Cascade Placement
$ #LeftRight
# Soldan saa
$ #RightLeft
# Sadan sola
$ #TopBottom
# stten aaa
$ #BottomTop
# Alttan ste
$ #Tabs
# Use Tabs
$ #Icons
# Use Icons
$ #TabPlacement
# Tab Placement
$ #TabRotateVertical
# Rotate Vertical Tabs
$ #SemiSloppyFocus
# Semi Sloppy Focus
$ #MaxOverSlit
# Maximize Over Slit
$ #SloppyWindowGrouping
# Sloppy Window Grouping
$ #WorkspaceWarping
# Workspace Warping
